chiark / gitweb /
Delimiter-setting function names change.
[fwd] / conf.c
diff --git a/conf.c b/conf.c
index d0c3f139c03c56727b1a690a035258c1c5793c05..0cd4a17809c16180b72042eaf19ab69f43cda11c 100644 (file)
--- a/conf.c
+++ b/conf.c
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: conf.c,v 1.7 2000/08/01 17:58:10 mdw Exp $
+ * $Id: conf.c,v 1.9 2002/01/13 14:48:16 mdw Exp $
  *
  * Configuration parsing
  *
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: conf.c,v $
+ * Revision 1.9  2002/01/13 14:48:16  mdw
+ * Make delimiters be a property of a scanner.  Change the delimiter-
+ * changing functions' names.
+ *
+ * Revision 1.8  2001/02/03 20:33:26  mdw
+ * Fix flags to be unsigned.
+ *
  * Revision 1.7  2000/08/01 17:58:10  mdw
  * Fix subtleties with <ctype.h> functions.
  *
@@ -84,14 +91,12 @@ static source_ops *sources[] =
 static target_ops *targets[] =
   { &xtarget_ops, &ftarget_ops, &starget_ops, 0 };
 
-static const char *notword = 0;
-static const char *notdelim = 0;
-
 /*----- Main code ---------------------------------------------------------*/
 
-/* --- @undelim@ --- *
+/* --- @conf_undelim@ --- *
  *
* Arguments:  @const char *d, dd@ = pointer to characters to escape
  *
  * Returns:    ---
  *
@@ -100,7 +105,11 @@ static const char *notdelim = 0;
  *             second list will always be allowed to continue a word.
  */
 
-void undelim(const char *d, const char *dd) { notword = d; notdelim = dd; }
+void conf_undelim(scanner *sc, const char *d, const char *dd)
+{
+  sc->wbegin = d;
+  sc->wcont = dd;
+}
 
 /* --- @token@ --- *
  *
@@ -156,7 +165,7 @@ int token(scanner *sc)
       /* --- Various self-delimiting characters --- */
 
       case SELFDELIM:
-       if (!notword || strchr(notword, ch) == 0) {
+       if (!sc->wbegin || strchr(sc->wbegin, ch) == 0) {
          dstr_putc(&sc->d, ch);
          dstr_putz(&sc->d);
          sc->t = ch;
@@ -186,7 +195,7 @@ int token(scanner *sc)
              q = !q;
              break;
            case SELFDELIM:
-             if (q || (notdelim && strchr(notdelim, ch)))
+             if (q || (sc->wcont && strchr(sc->wcont, ch)))
                goto insert;
              goto word;
            default:
@@ -380,16 +389,15 @@ int conf_prefix(scanner *sc, const char *p)
 void conf_name(scanner *sc, char delim, dstr *d)
 {
   unsigned f = 0;
-  enum {
-    f_ok = 1,
-    f_bra = 2
-  };
+
+#define f_ok 1u
+#define f_bra 2u
 
   /* --- Read an optional opening bracket --- */
 
   if (sc->t == '[') {
     token(sc);
-    f |= f_bra;
+    f |= f_bra | f_ok;
   }
 
   /* --- Do the main reading sequence --- */
@@ -421,6 +429,9 @@ void conf_name(scanner *sc, char delim, dstr *d)
       error(sc, "parse error, missing `]'");
   }
   DPUTZ(d);
+
+#undef f_ok
+#undef f_bra
 }
 
 /* --- @conf_parse@ --- *
@@ -84,14 +91,12 @@ static source_ops *sources[] =
  *
- * Arguments:  @const char *d, dd@ = pointer to characters to escape
+ * Arguments:  @scanner *sc@ = pointer to scanner definition
+ *             @const char *d, *dd@ = pointer to characters to escape
  *
  * Returns:    ---